# Bootstrap-Confirmation

[![npm version](https://img.shields.io/npm/v/bootstrap-confirmation2.svg?style=flat-square)](https://www.npmjs.com/package/bootstrap-confirmation2)
[![jsDelivr CDN](https://data.jsdelivr.com/v1/package/npm/bootstrap-confirmation2/badge)](https://www.jsdelivr.com/package/npm/bootstrap-confirmation2)
[![Build Status](https://img.shields.io/travis/mistic100/Bootstrap-Confirmation/master.svg?style=flat-square)](https://travis-ci.org/mistic100/Bootstrap-Confirmation)
[![Dependencies Status](https://david-dm.org/mistic100/Bootstrap-Confirmation/status.svg?style=flat-square)](https://david-dm.org/mistic100/Bootstrap-Confirmation)

Bootstrap plugin for on-place confirm boxes using Popover.

## Documentation

[bootstrap-confirmation.js.org](http://bootstrap-confirmation.js.org)

## Installation

#### Bootstrap 4

```
npm install bootstrap-confirmation2
```

#### Bootstrap 3

```
npm install bootstrap-confirmation2@2.x.x
```
